@@ -11,10 +11,10 @@
 from six import text_type
 
 
-class BaseUrlSigner(object):
+class BaseUrlSigner:
     def __init__(self, security_key):
         if isinstance(security_key, text_type):
-            security_key = security_key.encode('utf-8')
+            security_key = security_key.encode("utf-8")
         self.security_key = security_key
 
     def validate(self, actual_signature, url):
