@@ -8,55 +8,50 @@
 # http://www.opensource.org/licenses/mit-license
 # Copyright (c) 2011 Bernardo Heynemann heynemann@gmail.com
 
-'''libthumbor URL composer tests'''
-import sys
+# pylint: disable=no-self-use
+
+"""libthumbor URL composer tests"""
 from unittest import TestCase
 
-from libthumbor.url import url_for
-from libthumbor.url import unsafe_url
+from preggy import expect
 
-IMAGE_URL = 'my.server.com/some/path/to/image.jpg'
-IMAGE_MD5 = '84996242f65a4d864aceb125e1c4c5ba'
+from libthumbor.url import unsafe_url, url_for
 
-# def decrypt_in_thumbor(key, encrypted):
-#     '''Uses thumbor to decrypt libthumbor's encrypted URL'''
-#     crypto = Cryptor(key)
-#     return crypto.decrypt(encrypted)
+IMAGE_URL = "my.server.com/some/path/to/image.jpg"
+IMAGE_MD5 = "84996242f65a4d864aceb125e1c4c5ba"
 
 
 def test_no_options_specified():
-    '''test_no_options_specified
+    """test_no_options_specified
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
     When
         I ask my library for an URL
     Then
         I get "84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
+    """
     url = url_for(image_url=IMAGE_URL)
 
-    assert url == IMAGE_MD5, url
+    expect(url).to_equal(IMAGE_MD5)
 
 
 def test_url_raises_if_no_url():
-    '''test_url_raises_if_no_url
+    """test_url_raises_if_no_url
     Given
         An image URL of "" or null
     When
         I ask my library for an URL
     Then
         I get an exception that says image URL is mandatory
-    '''
-    try:
+    """
+    with expect.error_to_happen(
+        ValueError, message="The image_url argument is mandatory."
+    ):
         url_for()
-    except ValueError as err:
-        assert str(err) == 'The image_url argument is mandatory.'
-        return True
-    assert False, 'Should not have gotten this far'
 
 
 def test_url_width_height_1():
-    '''test_url_width_height_1
+    """test_url_width_height_1
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a width of 300
@@ -64,14 +59,14 @@ def test_url_width_height_1():
         I ask my library for an URL
     Then
         I get "300x0/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
+    """
     url = url_for(width=300, image_url=IMAGE_URL)
 
-    assert url == "300x0/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("300x0/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_url_width_height_2():
-    '''test_url_width_height_2
+    """test_url_width_height_2
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a height of 300
@@ -79,14 +74,14 @@ def test_url_width_height_2():
         I ask my library for an URL
     Then
         I get "0x300/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
+    """
     url = url_for(height=300, image_url=IMAGE_URL)
 
-    assert url == "0x300/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("0x300/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_url_width_height_3():
-    '''test_url_width_height_3
+    """test_url_width_height_3
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a width of 200
@@ -95,16 +90,14 @@ def test_url_width_height_3():
         I ask my library for an URL
     Then
         I get "200x300/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(width=200,
-                  height=300,
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(width=200, height=300, image_url=IMAGE_URL)
 
-    assert url == "200x300/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("200x300/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_url_width_height_4():
-    '''test_url_width_height_4
+    """test_url_width_height_4
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a width of orig
@@ -112,14 +105,14 @@ def test_url_width_height_4():
         I ask my library for an URL
     Then
         I get "origx0/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
+    """
     url = url_for(width="orig", image_url=IMAGE_URL)
 
-    assert url == "origx0/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("origx0/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_url_width_height_5():
-    '''test_url_width_height_5
+    """test_url_width_height_5
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a height of orig
@@ -127,14 +120,14 @@ def test_url_width_height_5():
         I ask my library for an URL
     Then
         I get "0xorig/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
+    """
     url = url_for(height="orig", image_url=IMAGE_URL)
 
-    assert url == "0xorig/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("0xorig/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_url_width_height_6():
-    '''test_url_width_height_6
+    """test_url_width_height_6
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a width of 100
@@ -143,14 +136,14 @@ def test_url_width_height_6():
         I ask my library for an URL
     Then
         I get "100xorig/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
+    """
     url = url_for(width=100, height="orig", image_url=IMAGE_URL)
 
-    assert url == "100xorig/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("100xorig/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_url_width_height_7():
-    '''test_url_width_height_7
+    """test_url_width_height_7
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a height of 100
@@ -159,14 +152,14 @@ def test_url_width_height_7():
         I ask my library for an URL
     Then
         I get "origx100/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
+    """
     url = url_for(width="orig", height=100, image_url=IMAGE_URL)
 
-    assert url == "origx100/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("origx100/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_url_width_height_8():
-    '''test_url_width_height_8
+    """test_url_width_height_8
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a height of orig
@@ -175,14 +168,14 @@ def test_url_width_height_8():
         I ask my library for an URL
     Then
         I get "origxorig/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
+    """
     url = url_for(width="orig", height="orig", image_url=IMAGE_URL)
 
-    assert url == "origxorig/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("origxorig/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_smart_url():
-    '''test_smart_url
+    """test_smart_url
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a width of 200
@@ -192,17 +185,14 @@ def test_smart_url():
         I ask my library for an URL
     Then
         I get "200x300/smart/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(width=200,
-                  height=300,
-                  smart=True,
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(width=200, height=300, smart=True, image_url=IMAGE_URL)
 
-    assert url == "200x300/smart/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("200x300/smart/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_fit_in_url():
-    '''test_fit_in_url
+    """test_fit_in_url
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a width of 200
@@ -212,17 +202,14 @@ def test_fit_in_url():
         I ask my library for an URL
     Then
         I get "fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(width=200,
-                  height=300,
-                  fit_in=True,
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(width=200, height=300, fit_in=True, image_url=IMAGE_URL)
 
-    assert url == "fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_adaptive_fit_in_url():
-    '''test_adaptive_fit_in_url
+    """test_adaptive_fit_in_url
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a width of 200
@@ -232,57 +219,50 @@ def test_adaptive_fit_in_url():
         I ask my library for an URL
     Then
         I get "adaptive-fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(width=200,
-                  height=300,
-                  adaptive_fit_in=True,
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(width=200, height=300, adaptive_fit_in=True, image_url=IMAGE_URL)
 
-    assert url == "adaptive-fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("adaptive-fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_fit_in_fails_if_no_width_supplied():
-    try:
+    with expect.error_to_happen(
+        ValueError,
+        message="When using fit-in or full-fit-in, "
+        "you must specify width and/or height.",
+    ):
         url_for(fit_in=True, image_url=IMAGE_URL)
-    except ValueError:
-        err = sys.exc_info()[1]
-        assert err is not None
-    else:
-        assert False, "Should not have gotten this far"
 
 
 def test_full_fit_in_fails_if_no_width_supplied():
-    try:
+    with expect.error_to_happen(
+        ValueError,
+        message="When using fit-in or full-fit-in, "
+        "you must specify width and/or height.",
+    ):
         url_for(full_fit_in=True, image_url=IMAGE_URL)
-    except ValueError:
-        err = sys.exc_info()[1]
-        assert err is not None
-    else:
-        assert False, "Should not have gotten this far"
 
 
 def test_adaptive_fit_in_fails_if_no_width_supplied():
-    try:
+    with expect.error_to_happen(
+        ValueError,
+        message="When using fit-in or full-fit-in, "
+        "you must specify width and/or height.",
+    ):
         url_for(adaptive_fit_in=True, image_url=IMAGE_URL)
-    except ValueError:
-        err = sys.exc_info()[1]
-        assert err is not None
-    else:
-        assert False, "Should not have gotten this far"
 
 
 def test_adaptive_full_fit_in_fails_if_no_width_supplied():
-    try:
+    with expect.error_to_happen(
+        ValueError,
+        message="When using fit-in or full-fit-in, "
+        "you must specify width and/or height.",
+    ):
         url_for(adaptive_full_fit_in=True, image_url=IMAGE_URL)
-    except ValueError:
-        err = sys.exc_info()[1]
-        assert err is not None
-    else:
-        assert False, "Should not have gotten this far"
 
 
 def test_full_fit_in_url():
-    '''test_full_fit_in_url
+    """test_full_fit_in_url
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a width of 200
@@ -292,17 +272,14 @@ def test_full_fit_in_url():
         I ask my library for an URL
     Then
         I get "full-fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(width=200,
-                  height=300,
-                  full_fit_in=True,
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(width=200, height=300, full_fit_in=True, image_url=IMAGE_URL)
 
-    assert url == "full-fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("full-fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_adaptive_full_fit_in_url():
-    '''test_adaptive_full_fit_in_url
+    """test_adaptive_full_fit_in_url
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a width of 200
@@ -312,17 +289,16 @@ def test_adaptive_full_fit_in_url():
         I ask my library for an URL
     Then
         I get "adaptive-full-fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(width=200,
-                  height=300,
-                  adaptive_full_fit_in=True,
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(width=200, height=300, adaptive_full_fit_in=True, image_url=IMAGE_URL)
 
-    assert url == "adaptive-full-fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal(
+        "adaptive-full-fit-in/200x300/84996242f65a4d864aceb125e1c4c5ba"
+    )
 
 
 def test_flip_1():
-    '''test_flip_1
+    """test_flip_1
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And the flip flag
@@ -330,15 +306,14 @@ def test_flip_1():
         I ask my library for an URL
     Then
         I get "-0x0/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(flip=True,
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(flip=True, image_url=IMAGE_URL)
 
-    assert url == "-0x0/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("-0x0/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_flip_2():
-    '''test_flip_2
+    """test_flip_2
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a width of 200
@@ -347,16 +322,14 @@ def test_flip_2():
         I ask my library for an URL
     Then
         I get "-200x0/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(flip=True,
-                  width=200,
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(flip=True, width=200, image_url=IMAGE_URL)
 
-    assert url == "-200x0/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("-200x0/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_flop_1():
-    '''test_flop_1
+    """test_flop_1
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And the flop flag
@@ -364,15 +337,14 @@ def test_flop_1():
         I ask my library for an URL
     Then
         I get "0x-0/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(flop=True,
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(flop=True, image_url=IMAGE_URL)
 
-    assert url == "0x-0/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("0x-0/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_flop_2():
-    '''test_flop_2
+    """test_flop_2
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a height of 200
@@ -381,16 +353,14 @@ def test_flop_2():
         I ask my library for an URL
     Then
         I get "0x-200/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(flop=True,
-                  height=200,
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(flop=True, height=200, image_url=IMAGE_URL)
 
-    assert url == "0x-200/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("0x-200/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_flip_flop():
-    '''test_flip_flop
+    """test_flip_flop
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And the flip flag
@@ -399,16 +369,14 @@ def test_flip_flop():
         I ask my library for an URL
     Then
         I get "-0x-0/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(flip=True,
-                  flop=True,
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(flip=True, flop=True, image_url=IMAGE_URL)
 
-    assert url == "-0x-0/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("-0x-0/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_flip_flop2():
-    '''test_flip_flop2
+    """test_flip_flop2
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a width of 200
@@ -419,18 +387,14 @@ def test_flip_flop2():
         I ask my library for an URL
     Then
         I get "-200x-300/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(flip=True,
-                  flop=True,
-                  width=200,
-                  height=300,
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(flip=True, flop=True, width=200, height=300, image_url=IMAGE_URL)
 
-    assert url == "-200x-300/84996242f65a4d864aceb125e1c4c5ba", url
+    expect(url).to_equal("-200x-300/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_horizontal_alignment():
-    '''test_horizontal_alignment
+    """test_horizontal_alignment
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a 'left' horizontal alignment option
@@ -438,15 +402,14 @@ def test_horizontal_alignment():
         I ask my library for an URL
     Then
         I get "left/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(halign='left',
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(halign="left", image_url=IMAGE_URL)
 
-    assert url == 'left/84996242f65a4d864aceb125e1c4c5ba', url
+    expect(url).to_equal("left/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_horizontal_alignment2():
-    '''test_horizontal_alignment2
+    """test_horizontal_alignment2
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a 'center' horizontal alignment option
@@ -454,15 +417,14 @@ def test_horizontal_alignment2():
         I ask my library for an URL
     Then
         I get "84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(halign='center',
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(halign="center", image_url=IMAGE_URL)
 
-    assert url == '84996242f65a4d864aceb125e1c4c5ba', url
+    expect(url).to_equal("84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_vertical_alignment():
-    '''test_vertical_alignment
+    """test_vertical_alignment
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a 'top' vertical alignment option
@@ -470,15 +432,14 @@ def test_vertical_alignment():
         I ask my library for an URL
     Then
         I get "top/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(valign='top',
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(valign="top", image_url=IMAGE_URL)
 
-    assert url == 'top/84996242f65a4d864aceb125e1c4c5ba', url
+    expect(url).to_equal("top/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_vertical_alignment2():
-    '''test_vertical_alignment2
+    """test_vertical_alignment2
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a 'middle' vertical alignment option
@@ -486,15 +447,14 @@ def test_vertical_alignment2():
         I ask my library for an URL
     Then
         I get "84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(valign='middle',
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(valign="middle", image_url=IMAGE_URL)
 
-    assert url == '84996242f65a4d864aceb125e1c4c5ba', url
+    expect(url).to_equal("84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_both_alignments():
-    '''test_both_alignments
+    """test_both_alignments
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a 'left' horizontal alignment option
@@ -503,38 +463,38 @@ def test_both_alignments():
         I ask my library for an URL
     Then
         I get "left/top/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(halign='left',
-                  valign='top',
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(halign="left", valign="top", image_url=IMAGE_URL)
 
-    assert url == 'left/top/84996242f65a4d864aceb125e1c4c5ba', url
+    expect(url).to_equal("left/top/84996242f65a4d864aceb125e1c4c5ba")
 
 
 def test_proper_haligns():
-    '''test_proper_haligns'''
-    try:
-        url_for(halign='wrong', image_url=IMAGE_URL)
-    except ValueError as err:
-        assert str(err) == 'Only "left", "center" and "right"' + \
-                           ' are valid values for horizontal alignment.'
-        return True
-    assert False, "Should not have gotten this far."
+    """test_proper_haligns"""
+    with expect.error_to_happen(
+        ValueError,
+        message=(
+            'Only "left", "center" and "right"'
+            " are valid values for horizontal alignment."
+        ),
+    ):
+        url_for(halign="wrong", image_url=IMAGE_URL)
 
 
 def test_proper_valigns():
-    '''test_proper_haligns'''
-    try:
-        url_for(valign='wrong', image_url=IMAGE_URL)
-    except ValueError as err:
-        assert str(err) == 'Only "top", "middle" and "bottom"' + \
-                           ' are valid values for vertical alignment.'
-        return True
-    assert False, "Should not have gotten this far."
+    """test_proper_haligns"""
+    with expect.error_to_happen(
+        ValueError,
+        message=(
+            'Only "top", "middle" and "bottom"'
+            " are valid values for vertical alignment."
+        ),
+    ):
+        url_for(valign="wrong", image_url=IMAGE_URL)
 
 
 def test_proper_meta():
-    '''test_proper_meta
+    """test_proper_meta
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a 'meta' flag
@@ -542,39 +502,34 @@ def test_proper_meta():
         I ask my library for an URL
     Then
         I get "meta/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(meta=True,
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(meta=True, image_url=IMAGE_URL)
 
-    assert url == 'meta/84996242f65a4d864aceb125e1c4c5ba', url
+    expect("meta/84996242f65a4d864aceb125e1c4c5ba").to_equal(url)
 
 
 def test_trim_standard():
-    url = url_for(trim=True,
-                  image_url=IMAGE_URL)
-    assert url == 'trim/84996242f65a4d864aceb125e1c4c5ba', url
+    url = url_for(trim=True, image_url=IMAGE_URL)
+    expect("trim/84996242f65a4d864aceb125e1c4c5ba").to_equal(url)
 
 
 def test_trim_pixel_and_tolerance():
-    url = url_for(trim=('bottom-right', 15),
-                  image_url=IMAGE_URL)
-    assert url == 'trim:bottom-right:15/84996242f65a4d864aceb125e1c4c5ba', url
+    url = url_for(trim=("bottom-right", 15), image_url=IMAGE_URL)
+    expect("trim:bottom-right:15/84996242f65a4d864aceb125e1c4c5ba").to_equal(url)
 
 
 def test_trim_pixel_only():
-    url = url_for(trim=('top-left', None),
-                  image_url=IMAGE_URL)
-    assert url == 'trim:top-left/84996242f65a4d864aceb125e1c4c5ba', url
+    url = url_for(trim=("top-left", None), image_url=IMAGE_URL)
+    expect("trim:top-left/84996242f65a4d864aceb125e1c4c5ba").to_equal(url)
 
 
 def test_trim_tolerance_only():
-    url = url_for(trim=(None, 15),
-                  image_url=IMAGE_URL)
-    assert url == 'trim::15/84996242f65a4d864aceb125e1c4c5ba', url
+    url = url_for(trim=(None, 15), image_url=IMAGE_URL)
+    expect("trim::15/84996242f65a4d864aceb125e1c4c5ba").to_equal(url)
 
 
 def test_manual_crop_1():
-    '''test_manual_crop_1
+    """test_manual_crop_1
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a manual crop left-top point of (10, 20)
@@ -583,15 +538,14 @@ def test_manual_crop_1():
         I ask my library for an URL
     Then
         I get "10x20:30x40/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(crop=((10, 20), (30, 40)),
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(crop=((10, 20), (30, 40)), image_url=IMAGE_URL)
 
-    assert url == '10x20:30x40/84996242f65a4d864aceb125e1c4c5ba', url
+    expect("10x20:30x40/84996242f65a4d864aceb125e1c4c5ba").to_equal(url)
 
 
 def test_manual_crop_2():
-    '''test_manual_crop_2
+    """test_manual_crop_2
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a manual crop left-top point of (0, 0)
@@ -600,15 +554,14 @@ def test_manual_crop_2():
         I ask my library for an URL
     Then
         I get "84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(crop=((0, 0), (0, 0)),
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(crop=((0, 0), (0, 0)), image_url=IMAGE_URL)
 
-    assert url == '84996242f65a4d864aceb125e1c4c5ba', url
+    expect("84996242f65a4d864aceb125e1c4c5ba").to_equal(url)
 
 
 def test_smart_after_alignments():
-    '''test_smart_after_alignments
+    """test_smart_after_alignments
     Given
         An image URL of "my.server.com/some/path/to/image.jpg"
         And a 'smart' flag
@@ -617,21 +570,22 @@ def test_smart_after_alignments():
         I ask my library for an URL
     Then
         I get "left/smart/84996242f65a4d864aceb125e1c4c5ba" as URL
-    '''
-    url = url_for(smart=True,
-                  halign='left',
-                  image_url=IMAGE_URL)
+    """
+    url = url_for(smart=True, halign="left", image_url=IMAGE_URL)
 
-    assert url == 'left/smart/84996242f65a4d864aceb125e1c4c5ba', url
+    expect("left/smart/84996242f65a4d864aceb125e1c4c5ba").to_equal(url)
 
 
 class UnsafeUrlTestCase(TestCase):
-
     def test_should_return_a_valid_unsafe_url_with_no_params(self):
-        self.assertEqual('unsafe/%s' % IMAGE_URL, unsafe_url(image_url=IMAGE_URL))
+        expect("unsafe/%s" % IMAGE_URL).to_equal(unsafe_url(image_url=IMAGE_URL))
 
     def test_should_return_an_unsafe_url_with_width_and_height(self):
-        self.assertEqual('unsafe/100x140/%s' % IMAGE_URL, unsafe_url(image_url=IMAGE_URL, width=100, height=140))
+        expect("unsafe/100x140/%s" % IMAGE_URL).to_equal(
+            unsafe_url(image_url=IMAGE_URL, width=100, height=140),
+        )
 
     def test_should_return_an_unsafe_url_with_crop_and_smart(self):
-        self.assertEqual('unsafe/100x140/smart/%s' % IMAGE_URL, unsafe_url(image_url=IMAGE_URL, width=100, height=140, smart=True))
+        expect("unsafe/100x140/smart/%s" % IMAGE_URL).to_equal(
+            unsafe_url(image_url=IMAGE_URL, width=100, height=140, smart=True),
+        )
